@@ -40,7 +40,7 @@ sub mk_compclass {
     my $staticdir = dir( $helper->{dir}, 'root', 'static' );
     $helper->mk_dir( $staticdir );
     $helper->render_file( style => file( $staticdir, 'pagingandsort.css' ) );
-    $helper->render_file( formfu_style => file( $staticdir, 'formfu.css' ) );
+    $helper->render_file( form_style => file( $staticdir, 'form.css' ) );
 
     # javascript
 #    $helper->mk_file( file( $staticdir, 'doubleselect.js' ),
@@ -185,27 +185,32 @@ __list__
     </td>
     <+ END +> 
     [% SET id = row.$pri %]
-    <td><a href="[% c.uri_for( 'view', <+ FOR key = primary_keys +>row.<+ key +>, <+ END +> ) %]">View</a></td>
-    <td><a href="[% c.uri_for( 'edit', <+ FOR key = primary_keys +>row.<+ key +>, <+ END +> ) %]">Edit</a></td>
-    <td><a href="[% c.uri_for( 'destroy', <+ FOR key = primary_keys +>row.<+ key +>, <+ END +> ) %]">Destroy</a></td>
+    <td><a href="[% c.uri_for( <+ IF rest +>'by_id'<+ ELSE +>'view'<+ END +>, <+ FOR key = primary_keys +>row.<+ key +>, <+ END +> ) %]">View</a></td>
+    <td><a href="[% c.uri_for( <+ IF rest +>'by_id'<+ ELSE +>'edit'<+ END +>, <+ FOR key = primary_keys +>row.<+ key +>, <+ END +><+ IF rest +>,'edit'<+ END +> ) %]">Edit</a></td>
+    <td><a href="[% c.uri_for( <+ IF rest +>'by_id'<+ ELSE +>'destroy'<+ END +>, <+ FOR key = primary_keys +>row.<+ key +>, <+ END +><+ IF rest +>,'destroy'<+ END +> ) %]">Destroy</a></td>
     </tr>
 [% END %]
 </table>
 [% PROCESS pager.tt %]
 <br/>
-<a href="[% c.uri_for( 'edit' ) %]">Add</a>
+<a href="[% c.uri_for( '<+ IF rest +>create_form<+ ELSE +>edit<+ END +>' ) %]">Add</a>
 
 __view__
 [% TAGS <+ +> %]
+<table name="view">
 <+ FOR column = field_configs +>
-<b><+ column.label +>:</b> 
+<tr>
+<td class="view_label"><b><+ column.label +>:</b></td>
+<td>
     <+ IF column.multiple +>
     [% FOR val = item.<+ column.name +>; val; ', '; END %]
     <+ ELSE +>
     [%  item.<+ column.name +> %]
     <+ END +>
-    <br/>
+</td>
+</tr>
 <+ END +>
+</table>
 <hr />
 <a href="[% c.uri_for( 'edit', <+ FOR key = primary_keys +>item.<+ key +>, <+ END +> ) %]">Edit</a>
 <hr />
@@ -220,8 +225,7 @@ __wrapper__
 <title>[% appname %]</title>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
 <link href="[%base%]static/pagingandsort.css" type="text/css" rel="stylesheet"/>
-<link href="[%base%]static/formfu.css" type="text/css" rel="stylesheet"/>
-<script src="[%base%]static/doubleselect.js" type="text/javascript" /></script>
+<link href="[%base%]static/form.css" type="text/css" rel="stylesheet"/>
 </head>
 <body>
 <div class="table_menu">
@@ -239,7 +243,7 @@ __edit__
 <br>
 <a href="[% c.uri_for( 'list' ) %]">List</a>
 <hr>
-[% form.html_table %]
+[% form %]
 __pager__
 [% IF pager %]
 <div class="pager">
@@ -282,7 +286,7 @@ __restricted__
 This is the restricted area - available only after loggin in.
 __home__
 This is an application generated by  
-<a href="http://search.cpan.org/~zby/Catalyst-Example-InstantCRUD-v0.0.9/lib/Catalyst/Example/InstantCRUD.pm">Catalyst::Example::InstantCRUD</a>
+<a href="http://search.cpan.org/dist/Catalyst-Example-InstantCRUD/lib/Catalyst/Example/InstantCRUD.pm">Catalyst::Example::InstantCRUD</a>
 - a generator of simple database applications for the 
 <a href="http://catalyst.perl.org">Catalyst</a> framework.
 See also 
@@ -294,28 +298,41 @@ __style__
 
 body {
     font: bold 12px Verdana, sans-serif;
+	background-color:#F8F8F8;
+	color: #00283F;
+}
+
+.table_menu {
+	text-align: center;
+	font-size: 16px;
+	padding: 15px 15px 15px 15px;
+	color: #7CBFE5;
 }
 
 .content {
-    padding: 12px;
-    margin-top: 1px;  
-    margin-bottom:0px;
-    margin-left: 15px; 
-    margin-right: 15px;
-    border-color: #000000;
-    border-top: 0px;
-    border-bottom: 0px;
-    border-left: 1px;
-    border-right: 1px;
+	clear: both;
+    padding: 30px 12px 12px 12px;
+	font-size: 16px;
+}
+
+hr {
+	border: 1px solid #7CBFE5;
+	margin: 10px 0 15px 0;
 }
 
 A { 
     text-decoration: none; 
-    color:#225 
+    color:#006DAC;
+	font-weight: bold;
 }
+
+A:visited { 
+    color:#0073B5;
+}
+
 A:hover { 
     text-decoration: underline; 
-    color:#222 
+    color:#006DAC; 
 }
 
 #title {
@@ -334,22 +351,30 @@ input.submit:hover {
 }
 
 table { 
-    border: 0px solid; 
+	margin: 0 auto 20px auto;
     background-color: #ffffff;
+	border-collapse: collapse;
+}
+
+table .view_label{ 
+    background-color: #DFF6E6;
 }
 
 th {
-    background-color: #b5cadc;
-    border: 1px solid #778;
-    font: bold 12px Verdana, sans-serif;
+    background-color: #DFF6E6;
+    border: 1px solid #7CBFE5;
+    font: bol 14px Verdana, sans-serif;
+	padding: 4px 4px 4px 4px;
 }
 
 tr.alternate { background-color:#e3eaf0; }
 tr:hover { background-color: #b5cadc; }
-td { font: 12px Verdana, sans-serif; }
 
-
-td { font: 12px Verdana, sans-serif; }
+td { 
+	font: 14px Verdana, sans-serif; 
+	border: 1px solid #7CBFE5;
+	padding: 4px 4px 4px 4px;
+}
 
 .action {
     border: 1px outset #7d95b5;
@@ -362,29 +387,34 @@ td { font: 12px Verdana, sans-serif; }
 }
 
 .pager {
-    font: 11px Arial, Helvetica, sans-serif;
+    font: bold 14px Verdana, sans-serif;
+    color: #7CBFE5; 
     text-align: center;
     border: solid 1px #e2e2e2;
     border-left: 0;
     border-right: 0;
-    padding-top: 10px;
-    padding-bottom: 10px;
-    margin: 0px;
-    background-color: #f3f6f8;
+    padding: 15px 0 15px 0;
+    background-color: #EBF8EF;
+}
+
+.pager .counter{
+	padding: 0 0 10px 0;
 }
 
 .pager a {
-    padding: 2px 6px;
-    border: solid 1px #ddd;
-    background: #fff;
+    padding: 2px 6px 2px 6px;
+}
+
+.pager a:hover {
+    color: #fff;
+    background: #7d95b5;
     text-decoration: none;
 }
 
-.pager a:visited {
+.pager .current {
     padding: 2px 6px;
-    border: solid 1px #ddd;
-    background: #fff;
-    text-decoration: none;
+    font-weight: bold;
+    vertical-align: top;
 }
 
 .pager .current-page {
@@ -392,297 +422,63 @@ td { font: 12px Verdana, sans-serif; }
     font-weight: bold;
     vertical-align: top;
 }
-
-.pager a:hover {
-    color: #fff;
-    background: #7d95b5;
-    border-color: #036;
-    text-decoration: none;
-}
-
-/* IDs */
-
-#widget_submit
-{
-	display: block;
-	margin: 0 0 1em 0;
-	border: 0 solid #000000;
-	border-top: 0 solid #000000;
-	padding: 0 1em 1em 1em;
-}
-
-#widget
-{
-	display: block;
-	margin: 0 0 1em 0;
-	border: 1px solid #FFFFFF;
-	/*border-top: 1px solid #000000;*/
-	padding: 0 1em 1em 1em;
-        background-color: #f3f6f8;
-        font: 11px sans-serif;
-}
-
-#widget fieldset
-{
-	display: block;
-	margin: 0 0 1em 0;
-	border: 0 solid #FFFFFF;
-	/*border-top: 1px solid #000000;*/
-	border-top: 0 solid #000000;
-	padding: 0 1em 1em 1em;
-}
-
-#widget fieldset.radio
-{
-	margin: 0 0 0 -1em;
-	border: 0 solid #FFFFFF;
-}
-
-#widget fieldset.radio input
-{
-	position: static;
-	clear: both;
-	float: left;
-        font: 12px sans-serif;
-}
-
-#widget fieldset.radio label
-{
-	position: relative;
-	top: -1.25em;
-	display: inline;
-	width: auto;
-	margin: 0 0 0 8em;
-	font-weight: bold;
-	font-weight: normal;
-}
-
-#widget fieldset.radio legend
-{
-	float: left;
-	font-weight: bold;
-}
-
-#widget input
-{
-	position: relative;
-	top: -1.4em;
-	left: 8em;
-	display: block;
-        font: 12px sans-serif;
-	font-weight: normal;
-}
-
-#widget input.submit
-{
-	clear: both;
-	display: block;
-	position: relative;
-	top: -1.4em;
-	left: 8em;
-}
-
-.allornone_errors,
-.equal_errors,
-.empty_errors,
-.in_errors,
-.ascii_errors,
-.any_errors,
-.callback_errors,
-.date_errors,
-.datetime_errors,
-.dependon_errors,
-.email_errors,
-.http_errors,
-.integer_errors,
-.lenght_errors,
-.maybe_errors,
-.number_errors,
-.printable_errors,
-.range_errors,
-.regex_errors,
-.string_errors,
-.time_errors,
-.all_errors      
-{
-        display: block;
-}
-
-.error_messages
-{
-        clear: right;
-        float: left;
-        display: block;
-        width: 80%;
-        margin-top: -15px;
-        margin-left: 96px;
-	padding-bottom: 0px;
-        font-weight: normal;
-        color: #d00;
-}
-
-.doubleselect
-{
-	display: block;
-}
-
-.doubleselect_left
-{
-	position: relative;
-        float: left;
-}
-
-.doubleselect_right
-{
-	position: relative;
-        float: left;
-        margin-left: 5px;
-}
-
-.doubleselect_buttons
-{
-	position: relative;
-        float: left;
-        margin-left: 5px;
-        margin-top: 20px;
-}
-
-.doubleselect_button_left
-{
-	position: relative;
-        float: left;
-}
-
-.doubleselect_button_right
-{
-	position: relative;
-        float: left;
-}
-
-.label_comments
-{
-        display: block;
-        width: 8em;
-        margin-top: 0px;
-        font: 11px sans-serif;
-        font-weight: normal;
-}
-
-#widget label
-{
-	clear: both;
-	float: left;
-	display: block;
-	width: 100%;
-	margin-top: 10px;
-	font-weight: bold;
-}
-
-#widget select
-{
-	position: relative;
-	top: -1.4em;
-	left: 8em;
-	display: block;
-	width: 10em;
-	font-weight: normal;
-        font: 12px sans-serif;
-}
-
-#widget textarea
-{
-	position: relative;
-	top: -1.4em;
-	left: 8em;
-	display: block;
-	font-weight: normal;
-        font: 12px sans-serif;
-}
-__formfu_style__
+__form_style__
 
 fieldset {
-	padding: 1em;
+	padding: 12px 12px 12px 12px;
+	border: 1px solid #7CBFE5;
+	background-color: #FFFFFF;	
 }
 
-fieldset .button,
-fieldset .checkbox,
-fieldset .contentbutton,
-fieldset .file,
-fieldset .image,
-fieldset .multi,
-fieldset .password,
-fieldset .radio,
-fieldset .reset,
-fieldset .select,
-fieldset .submit,
-fieldset .text,
-fieldset .textarea
+.main_fieldset {
+	font-size: 12px;
+}
+
+.main_fieldset fieldset {
+	margin: 20px 0 20px 0;	
+}
+
+fieldset input,
+fieldset password,
+fieldset radio,
+fieldset select,
+fieldset textarea
 {
-	display: block;
-	clear: left;
-	border: 0;
-	margin: 1px;
-	/* when no label */
-	margin-left: 12em;
+	margin: 8px 0 8px 0;
 }
 
-fieldset .button.label,
-fieldset .checkbox.label,
-fieldset .contentbutton.label,
-fieldset .file.label,
-fieldset .image.label,
-fieldset .multi.label,
-fieldset .password.label,
-fieldset .radio.label,
-fieldset .reset.label,
-fieldset .select.label,
-fieldset .submit.label,
-fieldset .text.label,
-fieldset .textarea.label
-{
-	margin-left: 1px;
+label {  
+	float: left;  
+	width: 120px;  
+	margin: 8px 10px 8px 0;	
+	text-align: right;
 }
 
-fieldset .error.label {
-	/* border + margin swap values with above, to ensure rows align */
-	border: 1px #fff;
-	margin: 0;
+.main_fieldset fieldset label{
+	width: 108px; 
+	font-weight: normal;
+	
 }
 
 fieldset .error_message {
        display: block;
        color: #ff0000;
-}
-
-fieldset .label .error_message {
-       /* padding-left eq label width + padding-right */
-       padding-left: 12em;
+	   margin: 20px 0 20px 0;
 }
 
 fieldset .error input,
 fieldset .error textarea,
 fieldset .error select {
-       background-color: #ffdddd;
+       background-color: #FFF0F0;
+	   border: 1px solid #ff0000;
 }
 
-fieldset .button label,
-fieldset .contentbutton label,
-fieldset .checkbox label,
-fieldset .file label,
-fieldset .image label,
-fieldset .multi label,
-fieldset .password label,
-fieldset .radio label,
-fieldset .radiogroup label,
-fieldset .select label,
-fieldset .text label,
-fieldset .textarea label
-{
-	display: inline;
-	float: left;
-	width: 11em;
-	text-align: right;
-	padding-right: 1em;
+#submit{
+	margin: 20px 0 10px 0;
+	padding: 2px 2px 2px 2px;
+	background-color:#DFF6E6;;
+    font: bold 14px Verdana, sans-serif;
+	color:#006DAC;
 }
 
 fieldset .radiogroup span label {
@@ -693,24 +489,6 @@ fieldset .radiogroup span label {
 	padding-right: 0;
 }
 
-fieldset .multi .elements {
-	display: block;
-	float: left;
-}
-
-fieldset .multi .elements label {
-	display: block;
-	width: auto;
-	padding-right: 0.25em;
-}
-
-fieldset .multi input,
-fieldset .multi select {
-	display: block;
-	float: left;
-	margin-right: 0.5em;
-}
-
 fieldset.checkboxgroup,
 fieldset.radiogroup
 {
@@ -725,79 +503,6 @@ fieldset.radiogroup.label {
 	margin-left: 0em;
 }
 
-fieldset .comment .comment {
-	/* when no label */
-	display: block;
-	margin-left: 0em;
-}
-
-fieldset .label .comment {
-	display: block;
-	margin-left: 12em;
-}
-
-/*** Alternative Layouts ***/
-
-fieldset .notes {
-	float: right;
-	width: 30%;
-	border: 1px dotted;
-}
-
-fieldset .multi.vertical input,
-fieldset.checkboxgroup.vertical input,
-fieldset.radiogroup.vertical input
-{
-	display: block;
-	float: left;
-	clear: left;
-}
-
-fieldset .multi.vertical select {
-	display: block;
-	float: left;
-	clear: right;
-}
-
-fieldset.checkboxgroup.vertical label,
-fieldset.radiogroup.vertical label
-{
-	display: block;
-	clear: right;
-}
-
-fieldset.radiogroup.vertical .subgroup {
-	float: left;
-}
-
-fieldset .fullwidth label
-{
-	display: block;
-	float: left;
-	width: auto;
-	text-align: left;
-}
-
-fieldset .fullwidth .error_message {
-       padding-left: 0em;
-}
-
-fieldset .fullwidth textarea
-{
-	display: block;
-	clear: left;
-	width: 30em;
-}
-
-fieldset .dojoeditor2 .RichTextEditable { /* Dojo::Editor2 */
-	display: inline;
-	float: left;
-	background-color: #ffc;
-	padding-bottom: 0.1em;
-}
-
-
-
 __END__
 
 =head1 NAME
